<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "(取消)激活地址簿错误。",
"id is not set." => "没有设置 id。",
"Cannot update addressbook with an empty name." => "无法使用一个空名称更新地址簿",
"No category name given." => "未指定类别名称。",
"Error adding group." => "添加分组错误。",
"Group ID missing from request." => "请求缺少分组ID。",
"Contact ID missing from request." => "请求缺少联系人ID。",
"No ID provided" => "未提供 ID",
"Error setting checksum." => "设置校验值错误。",
"No categories selected for deletion." => "未选中要删除的分类。",
"No address books found." => "找不到地址簿。",
"No contacts found." => "找不到联系人。",
"element name is not set." => "元素名称未设置",
"checksum is not set." => "未设置校验值。",
"Information about vCard is incorrect. Please reload the page." => "vCard 的信息不正确。请重新加载页面。",
"Information about vCard is incorrect. Please reload the page: " => "vCard 信息不正确。请刷新页面: ",
"Something went FUBAR. " => "有一些信息无法被处理。",
"Missing IM parameter." => "缺少即时通讯IM参数",
"Unknown IM: " => "未知即时通讯服务：",
"No contact ID was submitted." => "未提交联系人 ID。",
"Error reading contact photo." => "读取联系人照片时错误。",
"Error saving temporary file." => "保存临时文件错误。",
"The loading photo is not valid." => "载入的照片无效。",
"Contact ID is missing." => "缺少联系人 ID。",
"No photo path was submitted." => "未提供照片路径。",
"File doesn't exist:" => "文件不存在:",
"Error loading image." => "加载图片错误。",
"Error getting contact object." => "获取联系人对象时出错。",
"Error getting PHOTO property." => "获取照片属性时出错。",
"Error saving contact." => "保存联系人时出错。",
"Error resizing image" => "缩放图像时出错",
"Error cropping image" => "裁切图像时出错",
"Error creating temporary image" => "创建临时图像时出错",
"Error finding image: " => "查找图像时出错: ",
"Could not set preference: " => "无法设定偏好：",
"Error uploading contacts to storage." => "上传联系人到存储空间时出错",
"There is no error, the file uploaded with success" => "文件上传成功，没有错误发生",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "上传的文件长度超出了 php.ini 中 upload_max_filesize 的限制",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "上传的文件长度超出了 HTML 表单中 MAX_FILE_SIZE 的限制",
"The uploaded file was only partially uploaded" => "已上传文件只上传了部分（不完整）",
"No file was uploaded" => "没有文件被上传",
"Missing a temporary folder" => "缺少临时目录",
"Couldn't save temporary image: " => "无法保存临时图像: ",
"Couldn't load temporary image: " => "无法加载临时图像: ",
"No file was uploaded. Unknown error" => "没有文件被上传。未知错误",
"Contacts" => "联系人",
"Add to..." => "添加到……",
"Remove from..." => "从……删除",
"Add group..." => "添加分组……",
"Indexing contacts" => "正在索引联系人",
"Select photo" => "选择图片",
"Network or server error. Please inform administrator." => "网络或服务器错误。请通知管理员。",
"Error adding to group." => "添加到组时出错。",
"Error removing from group." => "从组删除时出错。",
"There was an error opening a mail composer." => "打开邮件撰写器时出错。",
"Deleting done. Click here to cancel reloading." => "删除完成。点击此处以取消重新载入。",
"Add address book" => "添加地址簿",
"Import done. Click here to cancel reloading." => "导入完毕。点击此处取消重载。",
"Not all files uploaded. Retrying..." => "仍有文件未上传，重试中",
"Something went wrong with the upload, please retry." => "上传中出现些问题，请重试。",
"Error" => "错误",
"Importing from {filename}..." => "正在导入 {文件名}...",
"Importing..." => "导入中",
"Unable to upload your file as it is a directory or has 0 bytes" => "无法上传您的文件，文件夹或者空文件",
"Upload Error" => "上传错误",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "您试图上传的文件超出了该服务器的最大文件限制",
"Upload too large" => "上传文件过大",
"Pending" => "等待",
"Add group" => "添加分组",
"No files selected for upload." => "没有选择文件以上传",
"Edit profile picture" => "编辑配置图片",
"Error loading profile picture." => "载入档案图片时出错",
"Enter name" => "输入姓名",
"Enter description" => "输入描述",
"Select addressbook" => "选择地址簿",
"The address book name cannot be empty." => "地址簿名称不能为空",
"Is this correct?" => "这正确吗？",
"There was an unknown error when trying to delete this contact" => "尝试删除这个联系人时出现一个未知错误。",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "一些联系人已被标注为删除，但是尚未完成，请稍候。",
"Click to undo deletion of {num} contacts" => "点击以撤销删除这{num}个联系人",
"Contact is already in this group." => "联系人已经在这个组中。",
"Contacts are already in this group." => "联系人都已经在这个组中。",
"Couldn't get contact list." => "无法获取联系人列表。",
"Contact is not in this group." => "联系人不在此分组中。",
"Contacts are not in this group." => "联系人都没有在这个组中。",
"A group named {group} already exists" => "分组{group}已存在。",
"You can drag groups to\narrange them as you like." => "你可以拖拽群组以你喜欢的方式摆放他们。",
"All" => "全部",
"Favorites" => "收藏",
"Shared by {owner}" => "共享人：{owner}",
"Result: " => "结果: ",
" imported, " => " 已导入， ",
" failed." => " 失败。",
"Displayname cannot be empty." => "显示名称不能为空",
"Show CardDav link" => "显示CardDav连接",
"Show read-only VCF link" => "显示只读VCF连接",
"Download" => "下载",
"Edit" => "编辑",
"Delete" => "删除",
"Cancel" => "取消",
"More..." => "更多",
"Less..." => "更少...",
"You do not have the permissions to read this addressbook." => "你没有权限查看地址簿",
"You do not have the permissions to update this addressbook." => "你没有权限更新此地址簿",
"There was an error updating the addressbook." => "更新地址簿时出错",
"You do not have the permissions to delete this addressbook." => "你没有权限编辑此地址簿",
"There was an error deleting this addressbook." => "删除地址簿时出错",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "工作",
"Home" => "家庭",
"Other" => "其它",
"Mobile" => "手机",
"Text" => "文本",
"Voice" => "语音",
"Message" => "消息",
"Fax" => "传真",
"Video" => "视频",
"Pager" => "传呼机",
"Internet" => "互联网",
"Friends" => "朋友",
"Family" => "家庭",
"There was an error deleting properties for this contact." => "删除这个联系人的属性时出现了一个错误。",
"{name}'s Birthday" => "{name} 的生日",
"Contact" => "联系人",
"You do not have the permissions to add contacts to this addressbook." => "您没有权限增加联系人到此地址簿",
"Could not find the vCard with ID." => "未能找到此 ID 的 vCard。",
"You do not have the permissions to edit this contact." => "你没有权限编辑此联系人",
"Could not find the vCard with ID: " => "无法找到联系人，根据ID：",
"Could not find the Addressbook with ID: " => "无法找到地址簿，根据ID：",
"You do not have the permissions to delete this contact." => "你没有权限删除此联系人",
"There was an error deleting this contact." => "删除联系人时出错。",
"Contact not found." => "找不到联系人。",
"HomePage" => "主页",
"New Group" => "新建分组",
"Settings" => "设置",
"Address books" => "地址簿",
"Import" => "导入",
"Select files to import" => "选择要导入的文件",
"Select files" => "选择文件",
"Import into:" => "导入至：",
"OK" => "OK",
"(De-)select all" => "反选全部",
"New Contact" => "新建联系人",
"Download Contact(s)" => "下载联系人",
"Groups" => "分组",
"Favorite" => "最爱",
"Delete Contact" => "删除联系人",
"Close" => "关闭",
"Keyboard shortcuts" => "快捷键",
"Navigation" => "导航",
"Next contact in list" => "列表中的下一个联系人",
"Previous contact in list" => "列表中的上一个联系人",
"Expand/collapse current addressbook" => "展开/收起此地址簿",
"Next addressbook" => "下一个地址簿",
"Previous addressbook" => "上一个地址簿",
"Actions" => "地址",
"Refresh contacts list" => "刷新联系人列表",
"Add new contact" => "新增联系人",
"Add new addressbook" => "新增地址簿",
"Delete current contact" => "删除当前联系人",
"<h3>You have no contacts in your addressbook.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>你的地址薄中没有联系人。</h3><p>添加一个新的联系人或者从VCF文件中导入。</p>",
"Add contact" => "添加联系人",
"Compose mail" => "编写邮件",
"Delete group" => "删除分组",
"Delete current photo" => "删除当前照片",
"Edit current photo" => "编辑当前照片",
"Upload new photo" => "上传新照片",
"Select photo from ownCloud" => "从 ownCloud 选择照片",
"First name" => "名",
"Additional names" => "其他名称",
"Last name" => "姓",
"Select groups" => "选择分组",
"Nickname" => "昵称",
"Enter nickname" => "输入昵称",
"Title" => "标题",
"Enter title" => "输入标题",
"Organization" => "组织",
"Enter organization" => "输入组织",
"Birthday" => "生日",
"Export as VCF" => "导出为 VCF",
"Add" => "增加",
"Phone" => "电话",
"Email" => "电子邮件",
"Instant Messaging" => "即时通讯",
"Address" => "地址",
"Note" => "注释",
"Web site" => "网址",
"Delete contact" => "删除联系人",
"Preferred" => "偏好",
"Please specify a valid email address." => "请指定合法的电子邮件地址",
"someone@example.com" => "someone@example.com",
"Mail to address" => "发送邮件到地址",
"Delete email address" => "删除电子邮件地址",
"Enter phone number" => "输入电话号码",
"Delete phone number" => "删除电话号码",
"Go to web site" => "访问网址",
"Delete URL" => "删除ＵＲＬ",
"View on map" => "在地图上显示",
"Delete address" => "删除地址",
"1 Main Street" => "1 主街道",
"Street address" => "街道地址",
"12345" => "12345",
"Postal code" => "邮政编码",
"Your city" => "城市",
"City" => "城市",
"Some region" => "部分地区",
"State or province" => "州/省",
"Your country" => "国家",
"Country" => "国家",
"Instant Messenger" => "即时通讯",
"Delete IM" => "删除即时通讯工具",
"Share" => "共享",
"Export" => "导出",
"CardDAV link" => "CardDAV 链接",
"The temporary image has been removed from cache." => "临时图像文件已从缓存中删除",
"CardDAV syncing addresses" => "CardDAV 同步地址",
"more info" => "更多信息",
"Primary address (Kontact et al)" => "首选地址 (Kontact 等)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "地址簿",
"New Address Book" => "新建地址簿",
"Name" => "姓名",
"Description" => "描述",
"Save" => "保存"
);
